@@ -8,7 +8,7 @@
 */
 
 #include "notification.h"
-#include "debug.h"
+#include "plasma_nm_kded.h"
 
 #include <uiutils.h>
 
@@ -22,6 +22,9 @@
 #include <QTimer>
 
 #include <algorithm>
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 Notification::Notification(QObject *parent)
     : QObject(parent)
@@ -68,7 +71,7 @@ void Notification::stateChanged(NetworkManager::Device::State newstate,
 {
     Q_UNUSED(oldstate)
 
-    NetworkManager::Device *device = qobject_cast<NetworkManager::Device *>(sender());
+    auto device = qobject_cast<NetworkManager::Device *>(sender());
     if (newstate == NetworkManager::Device::Activated && m_notifications.contains(device->uni())) {
         KNotification *notify = m_notifications.value(device->uni());
         notify->close();
@@ -269,7 +272,7 @@ void Notification::stateChanged(NetworkManager::Device::State newstate,
         notify->setText(text.toHtmlEscaped());
         notify->update();
     } else {
-        KNotification *notify = new KNotification(QStringLiteral("DeviceFailed"), KNotification::CloseOnTimeout);
+        auto notify = new KNotification(QStringLiteral("DeviceFailed"), KNotification::CloseOnTimeout);
         connect(notify, &KNotification::closed, this, &Notification::notificationClosed);
         notify->setProperty("uni", device->uni());
         notify->setComponentName(QStringLiteral("networkmanagement"));
@@ -307,7 +310,7 @@ void Notification::addActiveConnection(const NetworkManager::ActiveConnection::P
 
 void Notification::onActiveConnectionStateChanged(NetworkManager::ActiveConnection::State state)
 {
-    NetworkManager::ActiveConnection *ac = qobject_cast<NetworkManager::ActiveConnection *>(sender());
+    auto ac = qobject_cast<NetworkManager::ActiveConnection *>(sender());
 
     QString eventId, text, iconName;
     const QString acName = ac->id();
@@ -319,7 +322,7 @@ void Notification::onActiveConnectionStateChanged(NetworkManager::ActiveConnecti
         });
 
         if (foundConnection != m_activeConnectionsBeforeSleep.constEnd()) {
-            qCDebug(PLASMA_NM) << "Not emitting connection activated notification as the connection was active prior to suspend";
+            qCDebug(PLASMA_NM_KDED_LOG) << "Not emitting connection activated notification as the connection was active prior to suspend";
             return;
         }
 
@@ -341,12 +344,12 @@ void Notification::onActiveConnectionStateChanged(NetworkManager::ActiveConnecti
         }
     } else if (state == NetworkManager::ActiveConnection::Deactivated) {
         if (m_preparingForSleep) {
-            qCDebug(PLASMA_NM) << "Not emitting connection deactivated notification as we're about to suspend";
+            qCDebug(PLASMA_NM_KDED_LOG) << "Not emitting connection deactivated notification as we're about to suspend";
             return;
         }
 
         if (m_checkActiveConnectionOnResumeTimer && m_checkActiveConnectionOnResumeTimer->isActive()) {
-            qCDebug(PLASMA_NM) << "Not emitting connection deactivated notification as we've just woken up from suspend";
+            qCDebug(PLASMA_NM_KDED_LOG) << "Not emitting connection deactivated notification as we've just woken up from suspend";
             return;
         }
 
@@ -364,7 +367,7 @@ void Notification::onActiveConnectionStateChanged(NetworkManager::ActiveConnecti
             break;
         }
     } else {
-        qCWarning(PLASMA_NM) << "Unhandled active connection state change: " << state;
+        qCWarning(PLASMA_NM_KDED_LOG) << "Unhandled active connection state change: " << state;
         return;
     }
 
@@ -394,7 +397,7 @@ void Notification::onActiveConnectionStateChanged(NetworkManager::ActiveConnecti
 
 void Notification::onVpnConnectionStateChanged(NetworkManager::VpnConnection::State state, NetworkManager::VpnConnection::StateChangeReason reason)
 {
-    NetworkManager::VpnConnection *vpn = qobject_cast<NetworkManager::VpnConnection *>(sender());
+    auto vpn = qobject_cast<NetworkManager::VpnConnection *>(sender());
 
     QString eventId, text;
     const QString vpnName = vpn->connection()->name();
@@ -410,7 +413,7 @@ void Notification::onVpnConnectionStateChanged(NetworkManager::VpnConnection::St
         eventId = QStringLiteral("ConnectionDeactivated");
         text = i18n("VPN connection '%1' deactivated.", vpnName);
     } else {
-        qCWarning(PLASMA_NM) << "Unhandled VPN connection state change: " << state;
+        qCWarning(PLASMA_NM_KDED_LOG) << "Unhandled VPN connection state change: " << state;
         return;
     }
 
@@ -451,10 +454,10 @@ void Notification::onVpnConnectionStateChanged(NetworkManager::VpnConnection::St
         break;
     }
 
-    KNotification *notify = new KNotification(eventId, KNotification::CloseOnTimeout);
+    auto notify = new KNotification(eventId, KNotification::CloseOnTimeout);
     connect(notify, &KNotification::closed, this, &Notification::notificationClosed);
     notify->setProperty("uni", connectionId);
-    notify->setComponentName("networkmanagement");
+    notify->setComponentName(QStringLiteral("networkmanagement"));
     if (state == NetworkManager::VpnConnection::Activated) {
         notify->setIconName(QStringLiteral("dialog-information"));
     } else {
@@ -468,7 +471,7 @@ void Notification::onVpnConnectionStateChanged(NetworkManager::VpnConnection::St
 
 void Notification::notificationClosed()
 {
-    KNotification *notify = qobject_cast<KNotification *>(sender());
+    auto notify = qobject_cast<KNotification *>(sender());
     m_notifications.remove(notify->property("uni").toString());
 }
 
@@ -493,7 +496,7 @@ void Notification::onPrepareForSleep(bool sleep)
     } else {
         if (!m_checkActiveConnectionOnResumeTimer) {
             m_checkActiveConnectionOnResumeTimer = new QTimer(this);
-            m_checkActiveConnectionOnResumeTimer->setInterval(10000);
+            m_checkActiveConnectionOnResumeTimer->setInterval(10s);
             m_checkActiveConnectionOnResumeTimer->setSingleShot(true);
             connect(m_checkActiveConnectionOnResumeTimer, &QTimer::timeout, this, &Notification::onCheckActiveConnectionOnResume);
         }
@@ -520,11 +523,11 @@ void Notification::onCheckActiveConnectionOnResume()
         return;
     }
 
-    KNotification *notify = new KNotification(QStringLiteral("NoLongerConnected"), KNotification::CloseOnTimeout);
+    auto notify = new KNotification(QStringLiteral("NoLongerConnected"), KNotification::CloseOnTimeout);
     connect(notify, &KNotification::closed, this, &Notification::notificationClosed);
     const QString uni = QStringLiteral("offlineNotification");
     notify->setProperty("uni", uni);
-    notify->setComponentName("networkmanagement");
+    notify->setComponentName(QStringLiteral("networkmanagement"));
     notify->setIconName(QStringLiteral("dialog-warning"));
     notify->setTitle(i18n("No Network Connection"));
     notify->setText(i18n("You are no longer connected to a network."));
