@@ -43,9 +43,9 @@ private Q_SLOTS:
 
 private:
     NetworkManager::Security8021xSetting::Ptr m_setting;
-    Ui::Security8021x *m_ui;
-    QRegExpValidator *altSubjectValidator;
-    QRegExpValidator *serversValidator;
+    Ui::Security8021x *const m_ui;
+    QRegExpValidator *altSubjectValidator = nullptr;
+    QRegExpValidator *serversValidator = nullptr;
 };
 
 #endif // SECURITY8021X_H
