@@ -7,7 +7,7 @@
 #include "handler.h"
 #include "configuration.h"
 #include "connectioneditordialog.h"
-#include "debug.h"
+#include "plasma_nm_libs.h"
 #include "uiutils.h"
 
 #include <NetworkManagerQt/AccessPoint>
@@ -77,23 +77,21 @@ Handler::Handler(QObject *parent)
     }
 }
 
-Handler::~Handler()
-{
-}
+Handler::~Handler() = default;
 
 void Handler::activateConnection(const QString &connection, const QString &device, const QString &specificObject)
 {
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
 
     if (!con) {
-        qCWarning(PLASMA_NM) << "Not possible to activate this connection";
+        qCWarning(PLASMA_NM_LIBS_LOG) << "Not possible to activate this connection";
         return;
     }
 
     if (con->settings()->connectionType() == NetworkManager::ConnectionSettings::Vpn) {
         NetworkManager::VpnSetting::Ptr vpnSetting = con->settings()->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
         if (vpnSetting) {
-            qCDebug(PLASMA_NM) << "Checking VPN" << con->name() << "type:" << vpnSetting->serviceType();
+            qCDebug(PLASMA_NM_LIBS_LOG) << "Checking VPN" << con->name() << "type:" << vpnSetting->serviceType();
 
             bool pluginMissing = false;
 
@@ -117,9 +115,9 @@ void Handler::activateConnection(const QString &connection, const QString &devic
             }
 
             if (pluginMissing) {
-                qCWarning(PLASMA_NM) << "VPN" << vpnSetting->serviceType() << "not found, skipping";
-                KNotification *notification = new KNotification("MissingVpnPlugin", KNotification::CloseOnTimeout, this);
-                notification->setComponentName("networkmanagement");
+                qCWarning(PLASMA_NM_LIBS_LOG) << "VPN" << vpnSetting->serviceType() << "not found, skipping";
+                auto notification = new KNotification(QStringLiteral("MissingVpnPlugin"), KNotification::CloseOnTimeout, this);
+                notification->setComponentName(QStringLiteral("networkmanagement"));
                 notification->setTitle(con->name());
                 notification->setText(i18n("Missing VPN plugin"));
                 notification->setIconName(QStringLiteral("dialog-warning"));
@@ -138,12 +136,12 @@ void Handler::activateConnection(const QString &connection, const QString &devic
                 ModemManager::Modem::Ptr modem = mmModemDevice->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
                 NetworkManager::GsmSetting::Ptr gsmSetting = con->settings()->setting(NetworkManager::Setting::Gsm).staticCast<NetworkManager::GsmSetting>();
                 if (gsmSetting && gsmSetting->pinFlags() == NetworkManager::Setting::NotSaved && modem && modem->unlockRequired() > MM_MODEM_LOCK_NONE) {
-                    QDBusInterface managerIface("org.kde.plasmanetworkmanagement",
-                                                "/org/kde/plasmanetworkmanagement",
-                                                "org.kde.plasmanetworkmanagement",
+                    QDBusInterface managerIface(QStringLiteral("org.kde.plasmanetworkmanagement"),
+                                                QStringLiteral("/org/kde/plasmanetworkmanagement"),
+                                                QStringLiteral("org.kde.plasmanetworkmanagement"),
                                                 QDBusConnection::sessionBus(),
                                                 this);
-                    managerIface.call("unlockModem", mmModemDevice->uni());
+                    managerIface.call(QStringLiteral("unlockModem"), mmModemDevice->uni());
                     connect(modem.data(), &ModemManager::Modem::unlockRequiredChanged, this, &Handler::unlockRequiredChanged);
                     m_tmpConnectionPath = connection;
                     m_tmpDevicePath = device;
@@ -156,7 +154,7 @@ void Handler::activateConnection(const QString &connection, const QString &devic
 #endif
 
     QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::activateConnection(connection, device, specificObject);
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+    auto watcher = new QDBusPendingCallWatcher(reply, this);
     watcher->setProperty("action", Handler::ActivateConnection);
     watcher->setProperty("connection", con->name());
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
@@ -164,7 +162,7 @@ void Handler::activateConnection(const QString &connection, const QString &devic
 
 QString Handler::wifiCode(const QString &connectionPath, const QString &ssid, int _securityType) const
 {
-    NetworkManager::WirelessSecurityType securityType = static_cast<NetworkManager::WirelessSecurityType>(_securityType);
+    auto securityType = static_cast<NetworkManager::WirelessSecurityType>(_securityType);
 
     QString ret = QStringLiteral("WIFI:S:") + ssid + QLatin1Char(';');
     if (securityType != NetworkManager::NoneSecurity) {
@@ -172,14 +170,14 @@ QString Handler::wifiCode(const QString &connectionPath, const QString &ssid, in
         case NetworkManager::NoneSecurity:
             break;
         case NetworkManager::StaticWep:
-            ret += "T:WEP;";
+            ret += QStringLiteral("T:WEP;");
             break;
         case NetworkManager::WpaPsk:
         case NetworkManager::Wpa2Psk:
-            ret += "T:WPA;";
+            ret += QStringLiteral("T:WPA;");
             break;
         case NetworkManager::SAE:
-            ret += "T:SAE;";
+            ret += QStringLiteral("T:SAE;");
             break;
         default:
         case NetworkManager::DynamicWep:
@@ -205,7 +203,7 @@ QString Handler::wifiCode(const QString &connectionPath, const QString &ssid, in
     case NetworkManager::WpaPsk:
     case NetworkManager::Wpa2Psk:
     case NetworkManager::SAE:
-        pass = secret["psk"].toString();
+        pass = secret[QStringLiteral("psk")].toString();
         break;
     default:
         return {};
@@ -260,7 +258,7 @@ void Handler::addAndActivateConnection(const QString &device, const QString &spe
 
     if (securityType != NetworkManager::NoneSecurity) {
         wifiSecurity->setInitialized(true);
-        wifiSetting->setSecurity("802-11-wireless-security");
+        wifiSetting->setSecurity(QStringLiteral("802-11-wireless-security"));
     }
 
     if (securityType == NetworkManager::Leap //
@@ -312,7 +310,7 @@ void Handler::addAndActivateConnection(const QString &device, const QString &spe
             }
         }
         QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addAndActivateConnection(settings->toMap(), device, specificObject);
-        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+        auto watcher = new QDBusPendingCallWatcher(reply, this);
         watcher->setProperty("action", Handler::AddAndActivateConnection);
         watcher->setProperty("connection", settings->name());
         connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
@@ -324,9 +322,9 @@ void Handler::addAndActivateConnection(const QString &device, const QString &spe
 void Handler::addConnection(const NMVariantMapMap &map)
 {
     QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addConnection(map);
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+    auto watcher = new QDBusPendingCallWatcher(reply, this);
     watcher->setProperty("action", AddConnection);
-    watcher->setProperty("connection", map.value("connection").value("id"));
+    watcher->setProperty("connection", map.value(QStringLiteral("connection")).value(QStringLiteral("id")));
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
 }
 
@@ -335,7 +333,7 @@ void Handler::deactivateConnection(const QString &connection, const QString &dev
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
 
     if (!con) {
-        qCWarning(PLASMA_NM) << "Not possible to deactivate this connection";
+        qCWarning(PLASMA_NM_LIBS_LOG) << "Not possible to deactivate this connection";
         return;
     }
 
@@ -353,7 +351,7 @@ void Handler::deactivateConnection(const QString &connection, const QString &dev
         }
     }
 
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+    auto watcher = new QDBusPendingCallWatcher(reply, this);
     watcher->setProperty("action", Handler::DeactivateConnection);
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
 }
@@ -388,11 +386,11 @@ template<typename T>
 void makeDBusCall(const QDBusMessage &message, QObject *context, std::function<void(QDBusPendingReply<T>)> func)
 {
     QDBusPendingReply<T> reply = QDBusConnection::systemBus().asyncCall(message);
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, context);
+    auto watcher = new QDBusPendingCallWatcher(reply, context);
     QObject::connect(watcher, &QDBusPendingCallWatcher::finished, context, [func](QDBusPendingCallWatcher *watcher) {
         const QDBusPendingReply<T> reply = *watcher;
         if (!reply.isValid()) {
-            qCWarning(PLASMA_NM) << reply.error().message();
+            qCWarning(PLASMA_NM_LIBS_LOG) << reply.error().message();
             return;
         }
         func(reply);
@@ -400,9 +398,10 @@ void makeDBusCall(const QDBusMessage &message, QObject *context, std::function<v
     });
 }
 
-void setBluetoothEnabled(QString path, bool enabled)
+void setBluetoothEnabled(const QString &path, bool enabled)
 {
-    QDBusMessage message = QDBusMessage::createMethodCall("org.bluez", path, "org.freedesktop.DBus.Properties", "Set");
+    QDBusMessage message =
+        QDBusMessage::createMethodCall(QStringLiteral("org.bluez"), path, QStringLiteral("org.freedesktop.DBus.Properties"), QStringLiteral("Set"));
     QList<QVariant> arguments;
     arguments << QLatin1String("org.bluez.Adapter1");
     arguments << QLatin1String("Powered");
@@ -420,11 +419,11 @@ void Handler::enableBluetooth(bool enable)
     makeDBusCall<QMap<QDBusObjectPath, NMVariantMapMap>>(getObjects, this, [enable, this](const auto reply) {
         for (const QDBusObjectPath &path : reply.value().keys()) {
             const QString objPath = path.path();
-            qCDebug(PLASMA_NM) << "inspecting path" << objPath;
+            qCDebug(PLASMA_NM_LIBS_LOG) << "inspecting path" << objPath;
             const QStringList interfaces = reply.value().value(path).keys();
-            qCDebug(PLASMA_NM) << "interfaces:" << interfaces;
+            qCDebug(PLASMA_NM_LIBS_LOG) << "interfaces:" << interfaces;
 
-            if (!interfaces.contains("org.bluez.Adapter1")) {
+            if (!interfaces.contains(QStringLiteral("org.bluez.Adapter1"))) {
                 continue;
             }
 
@@ -465,7 +464,7 @@ void Handler::removeConnection(const QString &connection)
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
 
     if (!con || con->uuid().isEmpty()) {
-        qCWarning(PLASMA_NM) << "Not possible to remove connection " << connection;
+        qCWarning(PLASMA_NM_LIBS_LOG) << "Not possible to remove connection " << connection;
         return;
     }
 
@@ -478,7 +477,7 @@ void Handler::removeConnection(const QString &connection)
     }
 
     QDBusPendingReply<> reply = con->remove();
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+    auto watcher = new QDBusPendingCallWatcher(reply, this);
     watcher->setProperty("action", Handler::RemoveConnection);
     watcher->setProperty("connection", con->name());
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
@@ -487,7 +486,7 @@ void Handler::removeConnection(const QString &connection)
 void Handler::updateConnection(const NetworkManager::Connection::Ptr &connection, const NMVariantMapMap &map)
 {
     QDBusPendingReply<> reply = connection->update(map);
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+    auto watcher = new QDBusPendingCallWatcher(reply, this);
     watcher->setProperty("action", UpdateConnection);
     watcher->setProperty("connection", connection->name());
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
@@ -495,7 +494,7 @@ void Handler::updateConnection(const NetworkManager::Connection::Ptr &connection
 
 void Handler::requestScan(const QString &interface)
 {
-    for (NetworkManager::Device::Ptr device : NetworkManager::networkInterfaces()) {
+    for (const NetworkManager::Device::Ptr &device : NetworkManager::networkInterfaces()) {
         if (device->type() == NetworkManager::Device::Wifi) {
             NetworkManager::WirelessDevice::Ptr wifiDevice = device.objectCast<NetworkManager::WirelessDevice>();
 
@@ -516,7 +515,7 @@ void Handler::requestScan(const QString &interface)
                     } else if (lastRequestScan.isValid() && lastRequestScan.msecsTo(now) < NM_REQUESTSCAN_LIMIT_RATE) {
                         timeout = NM_REQUESTSCAN_LIMIT_RATE - lastRequestScan.msecsTo(now);
                     }
-                    qCDebug(PLASMA_NM) << "Rescheduling a request scan for" << wifiDevice->interfaceName() << "in" << timeout;
+                    qCDebug(PLASMA_NM_LIBS_LOG) << "Rescheduling a request scan for" << wifiDevice->interfaceName() << "in" << timeout;
                     scheduleRequestScan(wifiDevice->interfaceName(), timeout);
 
                     if (!interface.isEmpty()) {
@@ -528,9 +527,9 @@ void Handler::requestScan(const QString &interface)
                     delete m_wirelessScanRetryTimer.take(interface);
                 }
 
-                qCDebug(PLASMA_NM) << "Requesting wifi scan on device" << wifiDevice->interfaceName();
+                qCDebug(PLASMA_NM_LIBS_LOG) << "Requesting wifi scan on device" << wifiDevice->interfaceName();
                 QDBusPendingReply<> reply = wifiDevice->requestScan();
-                QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+                auto watcher = new QDBusPendingCallWatcher(reply, this);
                 watcher->setProperty("action", Handler::RequestScan);
                 watcher->setProperty("interface", wifiDevice->interfaceName());
                 connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
@@ -579,7 +578,7 @@ void Handler::createHotspot()
     }
 
     if (!wifiDev) {
-        qCWarning(PLASMA_NM) << "Failed to create hotspot: missing wireless device";
+        qCWarning(PLASMA_NM_LIBS_LOG) << "Failed to create hotspot: missing wireless device";
         return;
     }
 
@@ -619,7 +618,7 @@ void Handler::createHotspot()
 
     QDBusPendingReply<QDBusObjectPath, QDBusObjectPath, QVariantMap> reply =
         NetworkManager::addAndActivateConnection2(connectionSettings->toMap(), wifiDev->uni(), QString(), options);
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+    auto watcher = new QDBusPendingCallWatcher(reply, this);
     watcher->setProperty("action", Handler::CreateHotspot);
     watcher->setProperty("connection", Configuration::self().hotspotName());
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
@@ -658,8 +657,8 @@ bool Handler::checkRequestScanRateLimit(const NetworkManager::WirelessDevice::Pt
     ret |= lastRequestScan.isValid() && lastRequestScan.msecsTo(now) < NM_REQUESTSCAN_LIMIT_RATE;
     // skip the request scan
     if (ret) {
-        qCDebug(PLASMA_NM) << "Last scan finished " << lastScan.msecsTo(now) << "ms ago and last request scan was sent " << lastRequestScan.msecsTo(now)
-                           << "ms ago, Skipping scanning interface:" << wifiDevice->interfaceName();
+        qCDebug(PLASMA_NM_LIBS_LOG) << "Last scan finished " << lastScan.msecsTo(now) << "ms ago and last request scan was sent "
+                                    << lastRequestScan.msecsTo(now) << "ms ago, Skipping scanning interface:" << wifiDevice->interfaceName();
         return false;
     }
     return true;
@@ -765,37 +764,37 @@ void Handler::replyFinished(QDBusPendingCallWatcher *watcher)
         Handler::HandlerAction action = (Handler::HandlerAction)watcher->property("action").toUInt();
         switch (action) {
         case Handler::ActivateConnection:
-            notification = new KNotification("FailedToActivateConnection", KNotification::CloseOnTimeout, this);
+            notification = new KNotification(QStringLiteral("FailedToActivateConnection"), KNotification::CloseOnTimeout, this);
             notification->setTitle(i18n("Failed to activate %1", watcher->property("connection").toString()));
             break;
         case Handler::AddAndActivateConnection:
-            notification = new KNotification("FailedToAddConnection", KNotification::CloseOnTimeout, this);
+            notification = new KNotification(QStringLiteral("FailedToAddConnection"), KNotification::CloseOnTimeout, this);
             notification->setTitle(i18n("Failed to add %1", watcher->property("connection").toString()));
             break;
         case Handler::AddConnection:
-            notification = new KNotification("FailedToAddConnection", KNotification::CloseOnTimeout, this);
+            notification = new KNotification(QStringLiteral("FailedToAddConnection"), KNotification::CloseOnTimeout, this);
             notification->setTitle(i18n("Failed to add connection %1", watcher->property("connection").toString()));
             break;
         case Handler::DeactivateConnection:
-            notification = new KNotification("FailedToDeactivateConnection", KNotification::CloseOnTimeout, this);
+            notification = new KNotification(QStringLiteral("FailedToDeactivateConnection"), KNotification::CloseOnTimeout, this);
             notification->setTitle(i18n("Failed to deactivate %1", watcher->property("connection").toString()));
             break;
         case Handler::RemoveConnection:
-            notification = new KNotification("FailedToRemoveConnection", KNotification::CloseOnTimeout, this);
+            notification = new KNotification(QStringLiteral("FailedToRemoveConnection"), KNotification::CloseOnTimeout, this);
             notification->setTitle(i18n("Failed to remove %1", watcher->property("connection").toString()));
             break;
         case Handler::UpdateConnection:
-            notification = new KNotification("FailedToUpdateConnection", KNotification::CloseOnTimeout, this);
+            notification = new KNotification(QStringLiteral("FailedToUpdateConnection"), KNotification::CloseOnTimeout, this);
             notification->setTitle(i18n("Failed to update connection %1", watcher->property("connection").toString()));
             break;
         case Handler::RequestScan: {
             const QString interface = watcher->property("interface").toString();
-            qCWarning(PLASMA_NM) << "Wireless scan on" << interface << "failed:" << error;
+            qCWarning(PLASMA_NM_LIBS_LOG) << "Wireless scan on" << interface << "failed:" << error;
             scanRequestFailed(interface);
             break;
         }
         case Handler::CreateHotspot:
-            notification = new KNotification("FailedToCreateHotspot", KNotification::CloseOnTimeout, this);
+            notification = new KNotification(QStringLiteral("FailedToCreateHotspot"), KNotification::CloseOnTimeout, this);
             notification->setTitle(i18n("Failed to create hotspot %1", watcher->property("connection").toString()));
             break;
         default:
@@ -803,7 +802,7 @@ void Handler::replyFinished(QDBusPendingCallWatcher *watcher)
         }
 
         if (notification) {
-            notification->setComponentName("networkmanagement");
+            notification->setComponentName(QStringLiteral("networkmanagement"));
             notification->setText(error);
             notification->setIconName(QStringLiteral("dialog-warning"));
             notification->sendEvent();
@@ -814,26 +813,26 @@ void Handler::replyFinished(QDBusPendingCallWatcher *watcher)
 
         switch (action) {
         case Handler::AddConnection:
-            notification = new KNotification("ConnectionAdded", KNotification::CloseOnTimeout, this);
+            notification = new KNotification(QStringLiteral("ConnectionAdded"), KNotification::CloseOnTimeout, this);
             notification->setText(i18n("Connection %1 has been added", watcher->property("connection").toString()));
             break;
         case Handler::RemoveConnection:
-            notification = new KNotification("ConnectionRemoved", KNotification::CloseOnTimeout, this);
+            notification = new KNotification(QStringLiteral("ConnectionRemoved"), KNotification::CloseOnTimeout, this);
             notification->setText(i18n("Connection %1 has been removed", watcher->property("connection").toString()));
             break;
         case Handler::UpdateConnection:
-            notification = new KNotification("ConnectionUpdated", KNotification::CloseOnTimeout, this);
+            notification = new KNotification(QStringLiteral("ConnectionUpdated"), KNotification::CloseOnTimeout, this);
             notification->setText(i18n("Connection %1 has been updated", watcher->property("connection").toString()));
             break;
         case Handler::RequestScan:
-            qCDebug(PLASMA_NM) << "Wireless scan on" << watcher->property("interface").toString() << "succeeded";
+            qCDebug(PLASMA_NM_LIBS_LOG) << "Wireless scan on" << watcher->property("interface").toString() << "succeeded";
             break;
         default:
             break;
         }
 
         if (notification) {
-            notification->setComponentName("networkmanagement");
+            notification->setComponentName(QStringLiteral("networkmanagement"));
             notification->setTitle(watcher->property("connection").toString());
             notification->setIconName(QStringLiteral("dialog-information"));
             notification->sendEvent();
